@@ -2,7 +2,7 @@ from rest_framework import serializers
 
 from data.models.models import CalibrationConstants, Calibration, Channel, Accessory, HardwareConfig, PiPico, \
     DHT22, MCP3008, ModProbe, VEML7700, Hardware, Hub, SPIIo, SerialIo, PwmIo, I2cIo, DeviceFileIo, MCPAnalogIo, \
-    PiPicoAnalogIo, PiPicoACAnalogIo, PiGpio, DataTransformer,DataTransformerConstants
+    PiPicoAnalogIo, PiPicoACAnalogIo, PiGpio, DataTransformer,DataTransformerConstants,DataTransformerTypes,ChannelStats
 
 class RecursiveField(serializers.Serializer):
     def to_representation(self, value):
@@ -39,7 +39,7 @@ class ChannelStatsSerializer(serializers.ModelSerializer):
         except:
             return None
     class Meta:
-        model = CalibrationConstants
+        model = ChannelStats
         fields = ['channel', 'type', 'value','model']
 
 class ChannelSerializer(serializers.ModelSerializer):
@@ -54,7 +54,7 @@ class ChannelSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = Channel
-        fields = ['id', 'type', 'channel_index', 'hardware','channelstats','model']
+        fields = ['id', 'type', 'channel_index', 'hardware','channelstats','model','keep_statistics']
 
 
 
@@ -254,6 +254,10 @@ class DataTransformerConstantsSerializer(serializers.ModelSerializer):
         model = DataTransformerConstants
         fields = '__all__'
 
+class DataTransformerTypeSerializer(serializers.ModelSerializer):
+    class Meta:
+        model=DataTransformerTypes
+        fields = ['type']  # add here rest of the fields from model
 
 
 class DataTransformerTreeSerializer(serializers.ModelSerializer):
@@ -261,7 +265,7 @@ class DataTransformerTreeSerializer(serializers.ModelSerializer):
     channels = serializers.PrimaryKeyRelatedField(read_only=True,many=True)
     channel_stats = serializers.PrimaryKeyRelatedField(read_only=True,many=True)
     accessory = serializers.PrimaryKeyRelatedField(read_only=True)
-
+    type = serializers.StringRelatedField(many=False)
 
     children = serializers.SerializerMethodField(source='get_children')
     model = serializers.SerializerMethodField()
