@@ -155,10 +155,10 @@ class HardwareViewSet(viewsets.ModelViewSet):
 
     def getChannels(self, hardware_id):
         channels = Hardware.objects.get(pk=str(hardware_id)).channel_set.all()
-        serialized_hardware = ChannelSerializer(many=True).to_representation(channels)
+        serialized_channels = ChannelSerializer(channels,many=True).data
 
         # if request.accepted_renderer.format == 'html':
-        return JsonResponse(serialized_hardware, status=200, safe=False)
+        return JsonResponse(serialized_channels, status=200, safe=False)
 
     def getConfig(self, hardware_id):
         hardware_configs = Hardware.objects.get(pk=str(hardware_id)).hardwareconfig_set.all()
